@@ -314,6 +314,24 @@ def test_cli_with_azure_devops_with_python_312():
     )
 
 
+@pytest.mark.online
+def test_cli_with_azure_devops_with_python_314():
+    requirements_file = test_env.get_test_loc("azure-devops.req.txt")
+    expected_file = test_env.get_test_loc("azure-devops.req-314-expected.json", must_exist=False)
+    extra_options = [
+        "--operating-system",
+        "linux",
+        "--python-version",
+        "314",
+    ]
+    check_requirements_resolution(
+        requirements_file=requirements_file,
+        expected_file=expected_file,
+        extra_options=extra_options,
+        regen=REGEN_TEST_FIXTURES,
+    )
+
+
 @pytest.mark.online
 def test_cli_with_azure_devops_with_python_313():
     requirements_file = test_env.get_test_loc("azure-devops.req.txt")
